import { useState } from "react";
import { useRoute, useLocation } from "wouter";
import { useQuery, useMutation } from "@tanstack/react-query";
import { apiRequest, queryClient } from "@/lib/queryClient";
import { useToast } from "@/hooks/use-toast";
import { Badge } from "@/components/ui/badge";
import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
import {
  Carousel,
  CarouselContent,
  CarouselItem,
  CarouselNext,
  CarouselPrevious,
} from "@/components/ui/carousel";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from "@/components/ui/dialog";
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormMessage,
} from "@/components/ui/form";
import { Textarea } from "@/components/ui/textarea";
import { formatDistanceToNow } from "date-fns";
import { fr } from "date-fns/locale";
import { Heart, Clock, MapPin, Phone, Mail, AlertTriangle } from "lucide-react";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { z } from "zod";

// Message form schema
const messageSchema = z.object({
  content: z.string().min(10, "Le message doit contenir au moins 10 caractères"),
});

type MessageFormValues = z.infer<typeof messageSchema>;

const ListingDetail = () => {
  const [, navigate] = useLocation();
  const [match, params] = useRoute<{ id: string }>("/listings/:id");
  const { toast } = useToast();
  const [messageDialogOpen, setMessageDialogOpen] = useState(false);

  // Fetch current user
  const { data: userData } = useQuery<{ user: any }>({
    queryKey: ['/api/auth/current-user'],
    retry: false,
  });

  const isLoggedIn = !!userData?.user;

  // Fetch listing details
  const {
    data: listingData,
    isLoading,
    error,
  } = useQuery({
    queryKey: [`/api/listings/${params?.id}`],
    enabled: !!params?.id,
  });

  // Toggle favorite mutation
  const toggleFavoriteMutation = useMutation({
    mutationFn: async () => {
      if (!isLoggedIn) {
        throw new Error("Vous devez être connecté pour ajouter aux favoris");
      }

      if (listingData?.isFavorite) {
        await apiRequest('DELETE', `/api/favorites/${params?.id}`, {});
      } else {
        await apiRequest('POST', '/api/favorites', { listingId: params?.id });
      }
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: [`/api/listings/${params?.id}`] });
      queryClient.invalidateQueries({ queryKey: ['/api/favorites'] });
      
      toast({
        title: listingData?.isFavorite 
          ? "Retiré des favoris" 
          : "Ajouté aux favoris",
        description: listingData?.isFavorite 
          ? "L'annonce a été retirée de vos favoris" 
          : "L'annonce a été ajoutée à vos favoris",
      });
    },
    onError: (error) => {
      if (error.message === "Vous devez être connecté pour ajouter aux favoris") {
        toast({
          title: "Connexion requise",
          description: "Veuillez vous connecter pour ajouter des favoris",
          variant: "destructive",
        });
        navigate("/login");
      } else {
        toast({
          title: "Erreur",
          description: "Une erreur est survenue. Veuillez réessayer.",
          variant: "destructive",
        });
      }
    },
  });

  // Contact form setup
  const form = useForm<MessageFormValues>({
    resolver: zodResolver(messageSchema),
    defaultValues: {
      content: "",
    },
  });

  // Send message mutation
  const sendMessageMutation = useMutation({
    mutationFn: async (values: MessageFormValues) => {
      if (!isLoggedIn) {
        throw new Error("Vous devez être connecté pour envoyer un message");
      }

      await apiRequest('POST', '/api/messages', {
        content: values.content,
        listingId: parseInt(params?.id || "0"),
        receiverId: listingData?.seller.id,
      });
    },
    onSuccess: () => {
      toast({
        title: "Message envoyé",
        description: "Votre message a été envoyé avec succès",
      });
      form.reset();
      setMessageDialogOpen(false);
    },
    onError: (error) => {
      if (error.message === "Vous devez être connecté pour envoyer un message") {
        toast({
          title: "Connexion requise",
          description: "Veuillez vous connecter pour contacter le vendeur",
          variant: "destructive",
        });
        navigate("/login");
      } else {
        toast({
          title: "Erreur",
          description: "Une erreur est survenue lors de l'envoi du message",
          variant: "destructive",
        });
      }
    },
  });

  const onSubmit = (values: MessageFormValues) => {
    sendMessageMutation.mutate(values);
  };

  if (isLoading) {
    return (
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
          <div className="md:col-span-2 bg-gray-100 rounded-lg h-[400px] animate-pulse"></div>
          <div className="md:col-span-1 space-y-4">
            <div className="bg-gray-100 rounded-lg h-10 w-3/4 animate-pulse"></div>
            <div className="bg-gray-100 rounded-lg h-6 w-1/2 animate-pulse"></div>
            <div className="bg-gray-100 rounded-lg h-20 animate-pulse"></div>
            <div className="bg-gray-100 rounded-lg h-10 animate-pulse"></div>
          </div>
        </div>
      </div>
    );
  }

  if (error || !listingData) {
    return (
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        <Card>
          <CardContent className="pt-6 pb-6 text-center">
            <AlertTriangle className="h-12 w-12 text-red-500 mx-auto mb-4" />
            <h2 className="text-2xl font-bold mb-2">Annonce non trouvée</h2>
            <p className="text-gray-600 mb-4">
              Cette annonce n'existe pas ou a été supprimée.
            </p>
            <Button onClick={() => navigate("/")}>
              Retour à l'accueil
            </Button>
          </CardContent>
        </Card>
      </div>
    );
  }

  const { listing, images, seller, category, isFavorite } = listingData;
  
  // Format date
  const formattedDate = formatDistanceToNow(new Date(listing.createdAt), {
    addSuffix: true,
    locale: fr,
  });

  return (
    <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
      {/* Listing Title and actions */}
      <div className="mb-6">
        <div className="flex justify-between items-start">
          <div>
            <h1 className="text-3xl font-bold mb-2">{listing.title}</h1>
            <div className="flex items-center text-gray-500 text-sm space-x-4">
              <span className="flex items-center">
                <Clock className="h-4 w-4 mr-1" />
                {formattedDate}
              </span>
              <span className="flex items-center">
                <MapPin className="h-4 w-4 mr-1" />
                {listing.location}
              </span>
              {category && (
                <Badge variant="secondary">
                  {category.name}
                </Badge>
              )}
            </div>
          </div>
          <div className="text-3xl font-bold text-primary">
            {listing.price ? `${listing.price.toLocaleString('fr-FR')} €` : 'Prix non défini'}
          </div>
        </div>
      </div>

      {/* Main Content */}
      <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
        {/* Listing Images */}
        <div className="md:col-span-2">
          {images && images.length > 0 ? (
            <Carousel className="w-full">
              <CarouselContent>
                {images.map((image) => (
                  <CarouselItem key={image.id}>
                    <div className="overflow-hidden rounded-lg aspect-[4/3]">
                      <img
                        src={image.imageUrl}
                        alt={listing.title}
                        className="w-full h-full object-cover"
                      />
                    </div>
                  </CarouselItem>
                ))}
              </CarouselContent>
              <CarouselPrevious />
              <CarouselNext />
            </Carousel>
          ) : (
            <div className="bg-gray-200 rounded-lg aspect-[4/3] flex items-center justify-center">
              <span className="text-gray-400">Aucune image disponible</span>
            </div>
          )}

          {/* Listing Description */}
          <Card className="mt-6">
            <CardContent className="pt-6">
              <h2 className="text-xl font-bold mb-4">Description</h2>
              <div className="whitespace-pre-line text-gray-700">
                {listing.description}
              </div>
            </CardContent>
          </Card>
        </div>

        {/* Seller Info and Actions */}
        <div className="md:col-span-1">
          <Card>
            <CardContent className="pt-6">
              <h2 className="text-xl font-bold mb-4">Informations sur le vendeur</h2>
              <div className="flex items-center mb-4">
                <div className="bg-primary h-12 w-12 rounded-full flex items-center justify-center text-white font-bold text-lg mr-3">
                  {seller.username.charAt(0).toUpperCase()}
                </div>
                <div>
                  <p className="font-medium">{seller.username}</p>
                  <p className="text-sm text-gray-500">
                    {seller.isPro ? 'Professionnel' : 'Particulier'}
                  </p>
                </div>
              </div>

              {/* Contact Actions */}
              <div className="space-y-3 mt-6">
                <Dialog open={messageDialogOpen} onOpenChange={setMessageDialogOpen}>
                  <DialogTrigger asChild>
                    <Button className="w-full">
                      <Mail className="mr-2 h-4 w-4" />
                      Contacter le vendeur
                    </Button>
                  </DialogTrigger>
                  <DialogContent>
                    <DialogHeader>
                      <DialogTitle>Contacter {seller.username}</DialogTitle>
                      <DialogDescription>
                        Envoyez un message à propos de: {listing.title}
                      </DialogDescription>
                    </DialogHeader>
                    
                    <Form {...form}>
                      <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-4">
                        <FormField
                          control={form.control}
                          name="content"
                          render={({ field }) => (
                            <FormItem>
                              <FormControl>
                                <Textarea
                                  placeholder="Bonjour, je suis intéressé par votre annonce..."
                                  className="min-h-[120px]"
                                  {...field}
                                />
                              </FormControl>
                              <FormMessage />
                            </FormItem>
                          )}
                        />
                        
                        <div className="flex justify-end">
                          <Button
                            type="submit"
                            className="bg-primary hover:bg-primary/90"
                            disabled={sendMessageMutation.isPending}
                          >
                            {sendMessageMutation.isPending ? "Envoi..." : "Envoyer"}
                          </Button>
                        </div>
                      </form>
                    </Form>
                  </DialogContent>
                </Dialog>

                {seller.phoneNumber && (
                  <Button variant="outline" className="w-full">
                    <Phone className="mr-2 h-4 w-4" />
                    Appeler
                  </Button>
                )}

                <Button
                  variant="outline"
                  className="w-full"
                  onClick={() => toggleFavoriteMutation.mutate()}
                  disabled={toggleFavoriteMutation.isPending}
                >
                  <Heart className={`mr-2 h-4 w-4 ${isFavorite ? 'fill-primary' : ''}`} />
                  {isFavorite ? 'Retirer des favoris' : 'Ajouter aux favoris'}
                </Button>
              </div>

              {/* Safety Tips */}
              <div className="mt-6 border-t pt-4">
                <h3 className="font-medium text-sm mb-2">Conseils de sécurité</h3>
                <ul className="text-xs text-gray-600 space-y-1">
                  <li>• Ne payez jamais d'avance</li>
                  <li>• Rencontrez le vendeur dans un lieu public</li>
                  <li>• Vérifiez l'article avant d'acheter</li>
                  <li>• Signalez les annonces suspectes</li>
                </ul>
              </div>
            </CardContent>
          </Card>
        </div>
      </div>
    </div>
  );
};

export default ListingDetail;
